@@ -5,6 +5,7 @@ import cv2
 
 from smb3_eh_manip.app.opencv import Opencv
 from smb3_eh_manip.app.servers.fceux_lua_server import *
+from smb3_eh_manip.app.servers.livesplit_smb3manip import LivesplitSmb3Manip
 from smb3_eh_manip.app.servers.serial_server import SerialServer
 from smb3_eh_manip.app.state import State
 from smb3_eh_manip.ui.audio_player import AudioPlayer
@@ -27,6 +28,12 @@ class Controller:
         self.enable_audio_player = settings.get_boolean("enable_audio_player")
         self.enable_ui_player = settings.get_boolean("enable_ui_player")
         self.enable_opencv = settings.get_boolean("enable_opencv", fallback=True)
+        self.enable_serial_autoreset = settings.get_boolean(
+            "enable_serial_autoreset", fallback=False
+        )
+        self.enable_livesplit_smb3manip = settings.get_boolean(
+            "enable_livesplit_smb3manip", fallback=False
+        )
         self.offset_frames = settings.get_int("offset_frames", fallback=106)
         self.playing = False
         self.current_time = -1
@@ -44,6 +51,8 @@ class Controller:
             self.audio_player = AudioPlayer()
         if self.enable_ui_player:
             self.ui_player = UiPlayer()
+        if self.enable_livesplit_smb3manip:
+            self.livesplit_smb3manip = LivesplitSmb3Manip()
         events.listen(events.LagFramesObserved, self.handle_lag_frames_observed)
 
     def reset(self):
@@ -58,6 +67,8 @@ class Controller:
             taseditor.setplayback(self.offset_frames + latency_offset)
         if self.auto_detect_lag_frames_serial:
             self.serial_server.reset()
+        if self.enable_livesplit_smb3manip:
+            self.livesplit_smb3manip.reset()
 
     def start_playing(self):
         self.playing = True
@@ -75,6 +86,16 @@ class Controller:
             self.ui_player.reset()
         if self.enable_opencv:
             self.opencv.start_playing()
+        if self.enable_livesplit_smb3manip:
+            # need to send an abs/global time with offset already observed,
+            # since livesplit doesn't know about these offsets
+            start_time_ms = round(self.start_time * 1000)
+            offset_start_time = (
+                start_time_ms
+                - round(self.offset_frames * settings.NES_MS_PER_FRAME)
+                - self.latency_ms
+            )
+            self.livesplit_smb3manip.start_playing(offset_start_time)
 
     def terminate(self):
         if self.enable_opencv:
@@ -105,10 +126,12 @@ class Controller:
             if self.opencv.should_autoreset():
                 self.reset()
                 logging.info(f"Detected reset")
+        if self.enable_livesplit_smb3manip:
+            self.livesplit_smb3manip.tick(self.state, round(self.current_frame))
 
     def handle_lag_frames_observed(self, event: events.LagFramesObserved):
         if (
-            self.autoreset
+            self.enable_serial_autoreset
             and event.observed_load_frames > LOAD_FRAMES_AUTORESET_THRESHOLD
         ):
             self.reset()
